@@ -20,6 +20,9 @@ from redshift_client.sql_client import (
 from redshift_client.sql_client.connection import (
     DbConnection,
 )
+from redshift_client.sql_client.primitive import (
+    PrimitiveVal,
+)
 from redshift_client.sql_client.query import (
     Query,
 )
@@ -35,9 +38,6 @@ if TYPE_CHECKING:
     )
 else:
     CursorStub = Any
-InvalidType = _assert.InvalidType
-InvalidAssumption = _assert.InvalidAssumption
-PrimitiveVal = _assert.PrimitiveVal
 
 
 @dataclass(frozen=True)
