@@ -25,12 +25,9 @@ class _Table:
 
 
 @dataclass(frozen=True)
-class Table:
-    _inner: _Table
-
-    @property
-    def columns(self) -> FrozenDict[ColumnId, Column]:
-        return self._inner.columns
+class Table(_Table):
+    def __init__(self, obj: _Table) -> None:
+        super().__init__(obj.columns, obj.primary_keys)
 
 
 def new(
